@@ -1,12 +1,12 @@
 package Class::Type::Enum;
 # ABSTRACT: Build Enum-like classes
-$Class::Type::Enum::VERSION = '0.001';
+$Class::Type::Enum::VERSION = '0.002';
 
 use strict;
 use warnings;
 
 use Function::Parameters ':strict';
-use List::Util ();
+use List::Util v1.33 ();
 use Scalar::Util qw(blessed);
 use Class::Method::Modifiers qw(install_modifier);
 
@@ -31,11 +31,8 @@ fun import ($class, %params) {
   my %values;
 
   if (ref $params{values} eq 'ARRAY') {
-    my $i = $params{init} // 0;
-
-    %values = map {
-      $_ => ($params{bits} ? 2**($i++) : $i++)
-    } @{$params{values}};
+    my $i = 0;
+    %values = map { $_ => $i++ } @{$params{values}};
   }
   elsif (ref $params{values} eq 'HASH') {
     %values = %{$params{values}};
@@ -49,11 +46,11 @@ fun import ($class, %params) {
     no strict 'refs';
     push @{"${target}::ISA"}, $class;
   }
-  install_modifier $target, 'fresh', values_ord => sub { \%values };
-  install_modifier $target, 'fresh', ord_values => sub { +{ reverse(%values) } };
+  install_modifier $target, 'fresh', sym_to_ord => sub { \%values };
+  install_modifier $target, 'fresh', ord_to_sym => sub { +{ reverse(%values) } };
 
   install_modifier $target, 'fresh', values => method {
-    my $ord = $self->values_ord;
+    my $ord = $self->sym_to_ord;
     [ sort { $ord->{$a} <=> $ord->{$b} } keys %values ];
   };
 
@@ -65,58 +62,69 @@ fun import ($class, %params) {
 
 
 method new ($class: $value) {
-  $class->inflate_value($value);
+  (blessed($class)// $class)->inflate_symbol($value);
 }
 
 
-method inflate_value ($class: $value) {
+method inflate_symbol ($class: $symbol) {
   bless {
-    ord => $class->values_ord->{$value}
-        // die "Value [$value] is not valid for enum $class"
+    ord => $class->sym_to_ord->{$symbol}
+        // die "Value [$symbol] is not valid for enum $class"
   }, $class;
 }
 
 
-method inflate ($class: $ord) {
-  die "Ordinal $ord is not valid for enum $class"
-    if !exists $class->ord_values->{$ord};
+method inflate_ordinal ($class: $ord) {
+  die "Ordinal [$ord] is not valid for enum $class"
+    if !exists $class->ord_to_sym->{$ord};
   bless { ord => $ord }, $class;
 }
 
 
-method get_test ($class:) {
-  return fun ($value) {
-    exists($class->values_ord->{$value})
-      or die "Value [$value] is not valid for enum $class"
-  }
+method test_symbol ($class: $value) {
+  exists($class->sym_to_ord->{$value})
 }
 
 
-
-method test ($class: $value) {
-  $class->get_test->($value)
+method test_ordinal ($class: $value) {
+  exists($class->ord_to_sym->{$value})
 }
 
 
+method coerce_symbol ($class: $value) {
+  return $value if eval { $value->isa($class) };
 
-method get_coerce ($class:) {
-  return fun ($value) {
-    eval { $value->isa($class) }
-      ? $value
-      : $class->new($value);
+  $class->inflate_symbol($value);
+}
+
+
+method coerce_ordinal ($class: $value) {
+  return $value if eval { $value->isa($class) };
+
+  $class->inflate_ordinal($value);
+}
+
+
+method coerce_any ($class: $value) {
+  return $value if eval { $value->isa($class) };
+
+  for my $method (qw( inflate_ordinal inflate_symbol )) {
+    my $enum = eval { $class->$method($value) };
+    return $enum if $enum;
   }
+  die "Could not coerce invalid value [$value] into $class";
 }
 
 
 
 method is ($value) {
-  $self->{ord} == ($self->values_ord->{$value} // die "Value [$value] is not valid for enum ". blessed($self))
+  $self->{ord} == ($self->sym_to_ord->{$value} // die "Value [$value] is not valid for enum ". blessed($self))
 }
 
 
 
 method stringify {
-  $self->ord_values->{$self->{ord}};
+  $self->ord_to_sym->{$self->{ord}};
 }
 
 
@@ -151,7 +159,7 @@ Class::Type::Enum - Build Enum-like classes
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -203,31 +211,31 @@ Required:
 
 The list of symbolic values in your enum, in ascending order if relevant.
 
-=back
+=item values => {symbol => ordinal, ...}
 
-=item *
-
-Optional
-
-=over 4
-
-=item init => $integer // 0
-
-If provided, the ordinal values of your enum will begin with the init value.
-
-=item bits => $bool // !!0
-
-If true, each ordinal will be an increasing power of two, rather than
-increments.  That is, with this set, your enum's ordinal values will be 1, 2,
-4, 8, 16, ... which can be handy for bit fields.
+The list of symbols and ordinal values in your enum.  There is no check that a
+given ordinal isn't reused.
 
 =back
 
 =back
 
+=head2 Custom Ordinal Values
+
+If you'd like to build an enum that works like a bitfield or some other custom
+setup, you need only pass a more explicit hashref to Class::Type::Enum.
+
+  package BitField {
+    use Class::Type::Enum values => {
+      READ    => 1,
+      WRITE   => 2,
+      EXECUTE => 4,
+    };
+  }
+
 =head1 METHODS
 
-=head2 $class->import(values => [], ...)
+=head2 $class->import(values => ...)
 
 Sets up the consuming class as a subclass of Class::Type::Enum and installs
 functions that are unique to the class.
@@ -235,54 +243,59 @@ functions that are unique to the class.
 =head2 $class->new($value)
 
 Your basic constructor, expects only a value corresponding to a symbol in the
-enum type.
+enum type.  Also works as an instance method for enums of the same class.
 
-=head2 $class->inflate_value($value)
+=head2 $class->inflate_symbol($symbol)
 
 Does the actual work of L<$class-E<gt>new($value)>, also used when inflating values for
 L<DBIx::Class::InflateColumn::ClassTypeEnum>.
 
-=head2 $class->inflate($ord)
+=head2 $class->inflate_ordinal($ord)
 
 Used when inflating ordinal values for
 L<DBIx::Class::InflateColumn::ClassTypeEnum> or if you need to work with
 ordinals directly.
 
-=head2 $class->values_ord
+=head2 $class->sym_to_ord
 
-Returns a hashref with symbols as keys and ordinals as values.
+Returns a hashref keyed by symbol, with ordinals as values.
 
-=head2 $class->ord_values
+=head2 $class->ord_to_sym
 
-Returns a hashref with ordinals as keys and symbols as values.
+Returns a hashref keyed by ordinal, with symbols as values.
 
 =head2 $class->values
 
-Returns an arrayref of valid symbolic values in order.
+Returns an arrayref of valid symbolic values, in order.
 
-=head2 $class->get_test
+=head2 $class->test_symbol($value)
 
-Returns a function which either returns true if it's passed a valid value for
-the enum, or throws an exception.
+Test whether or not the given value is a valid symbol in this enum class.
 
-=head2 $class->test($value)
+=head2 $class->test_ordinal($value)
 
-A helper for directly using L<$class-E<gt>get_test>.
+Test whether or not the given value is a valid ordinal in this enum class.
 
-  Toast::Status->test('deleted')   # throws an exception
+=head2 $class->coerce_symbol($value)
 
-=head2 $class->get_coerce
+If the given value is already a $class, return it, otherwise try to inflate it
+as a symbol.  Dies on invalid value.
 
-Returns a function which returns an enum if given an enum, or tries to create an enum from the given value using L<$class-E<gt>new($value)>.
+=head2 $class->coerce_ordinal($value)
 
-TODO: test and coerce don't work with ordinals
+If the given value is already a $class, return it, otherwise try to inflate it
+as an ordinal.  Dies on invalid value.
+
+=head2 $class->coerce_any($value)
+
+If the given value is already a $class, return it, otherwise try to inflate it
+first as an ordinal, then as a symbol.  Dies on invalid value.
 
 =head2 $o->is($value)
 
-Given a test value, returns true or false if the enum instance's value is equal
-to the test value.
+Given a test symbol, test that the enum instance's value is equivalent.
 
-An exception is thrown if an invalid test value is given.
+An exception is thrown if an invalid symbol is provided
 
 =head2 $o->is_$value
 
